@@ -24,7 +24,11 @@
 extern zend_module_entry geoip_module_entry;
 #define phpext_geoip_ptr &geoip_module_entry
 
-#define PHP_GEOIP_VERSION "1.1.0"
+#define PHP_GEOIP_VERSION "1.1.1"
+
+#if PHP_MAJOR_VERSION < 7
+typedef long zend_long;
+#endif
 
 #ifdef PHP_WIN32
 #define PHP_GEOIP_API __declspec(dllexport)
